@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -61,7 +61,7 @@ __all__ = ("ElasticTranscoderClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -79,7 +79,7 @@ class Exceptions:
 
 class ElasticTranscoderClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html)
     """
 
@@ -95,7 +95,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#can_paginate)
         """
 
@@ -103,7 +103,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The CancelJob operation cancels an unfinished job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#cancel_job)
         """
 
@@ -112,18 +112,18 @@ class ElasticTranscoderClient(BaseClient):
         *,
         PipelineId: str,
         Input: "JobInputTypeDef" = None,
-        Inputs: List["JobInputTypeDef"] = None,
+        Inputs: Sequence["JobInputTypeDef"] = None,
         Output: "CreateJobOutputTypeDef" = None,
-        Outputs: List["CreateJobOutputTypeDef"] = None,
+        Outputs: Sequence["CreateJobOutputTypeDef"] = None,
         OutputKeyPrefix: str = None,
-        Playlists: List["CreateJobPlaylistTypeDef"] = None,
-        UserMetadata: Dict[str, str] = None
+        Playlists: Sequence["CreateJobPlaylistTypeDef"] = None,
+        UserMetadata: Mapping[str, str] = None
     ) -> CreateJobResponseTypeDef:
         """
         When you create a job, Elastic Transcoder returns JSON data that includes the
         values that you specified plus information about the job that is created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_job)
         """
 
@@ -142,7 +142,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The CreatePipeline operation creates a pipeline with settings that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_pipeline)
         """
 
@@ -159,7 +159,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The CreatePreset operation creates a preset with settings that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_preset)
         """
 
@@ -167,7 +167,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The DeletePipeline operation removes a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_pipeline)
         """
 
@@ -175,21 +175,21 @@ class ElasticTranscoderClient(BaseClient):
         """
         The DeletePreset operation removes a preset that you've added in an AWS region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_preset)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#generate_presigned_url)
         """
 
@@ -200,7 +200,7 @@ class ElasticTranscoderClient(BaseClient):
         The ListJobsByPipeline operation gets a list of the jobs currently in a
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_pipeline)
         """
 
@@ -210,7 +210,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The ListJobsByStatus operation gets a list of jobs that have a specified status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_status)
         """
 
@@ -221,7 +221,7 @@ class ElasticTranscoderClient(BaseClient):
         The ListPipelines operation gets a list of the pipelines associated with the
         current AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_pipelines)
         """
 
@@ -232,7 +232,7 @@ class ElasticTranscoderClient(BaseClient):
         The ListPresets operation gets a list of the default presets included with
         Elastic Transcoder and the presets that you've added in an AWS region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_presets)
         """
 
@@ -240,7 +240,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The ReadJob operation returns detailed information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_job)
         """
 
@@ -248,7 +248,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         The ReadPipeline operation gets detailed information about a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_pipeline)
         """
 
@@ -256,17 +256,17 @@ class ElasticTranscoderClient(BaseClient):
         """
         The ReadPreset operation gets detailed information about a preset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_preset)
         """
 
     def test_role(
-        self, *, Role: str, InputBucket: str, OutputBucket: str, Topics: List[str]
+        self, *, Role: str, InputBucket: str, OutputBucket: str, Topics: Sequence[str]
     ) -> TestRoleResponseTypeDef:
         """
         The TestRole operation tests the IAM role used to create the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#test_role)
         """
 
@@ -285,7 +285,7 @@ class ElasticTranscoderClient(BaseClient):
         """
         Use the `UpdatePipeline` operation to update settings for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline)
         """
 
@@ -296,7 +296,7 @@ class ElasticTranscoderClient(BaseClient):
         With the UpdatePipelineNotifications operation, you can update Amazon Simple
         Notification Service (Amazon SNS) notifications for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_notifications)
         """
 
@@ -307,7 +307,7 @@ class ElasticTranscoderClient(BaseClient):
         The UpdatePipelineStatus operation pauses or reactivates a pipeline, so that the
         pipeline stops or restarts the processing of jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_status)
         """
 
@@ -316,7 +316,7 @@ class ElasticTranscoderClient(BaseClient):
         self, operation_name: Literal["list_jobs_by_pipeline"]
     ) -> ListJobsByPipelinePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
         """
 
@@ -325,26 +325,26 @@ class ElasticTranscoderClient(BaseClient):
         self, operation_name: Literal["list_jobs_by_status"]
     ) -> ListJobsByStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_presets"]) -> ListPresetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
         """
 
     def get_waiter(self, waiter_name: Literal["job_complete"]) -> JobCompleteWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
         """
