@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -159,8 +159,8 @@ CaptionsTypeDef = TypedDict(
     "CaptionsTypeDef",
     {
         "MergePolicy": str,
-        "CaptionSources": List["CaptionSourceTypeDef"],
-        "CaptionFormats": List["CaptionFormatTypeDef"],
+        "CaptionSources": Sequence["CaptionSourceTypeDef"],
+        "CaptionFormats": Sequence["CaptionFormatTypeDef"],
     },
     total=False,
 )
@@ -182,9 +182,9 @@ CreateJobOutputTypeDef = TypedDict(
         "Rotate": str,
         "PresetId": str,
         "SegmentDuration": str,
-        "Watermarks": List["JobWatermarkTypeDef"],
+        "Watermarks": Sequence["JobWatermarkTypeDef"],
         "AlbumArt": "JobAlbumArtTypeDef",
-        "Composition": List["ClipTypeDef"],
+        "Composition": Sequence["ClipTypeDef"],
         "Captions": "CaptionsTypeDef",
         "Encryption": "EncryptionTypeDef",
     },
@@ -196,7 +196,7 @@ CreateJobPlaylistTypeDef = TypedDict(
     {
         "Name": str,
         "Format": str,
-        "OutputKeys": List[str],
+        "OutputKeys": Sequence[str],
         "HlsContentProtection": "HlsContentProtectionTypeDef",
         "PlayReadyDrm": "PlayReadyDrmTypeDef",
     },
@@ -213,12 +213,12 @@ _OptionalCreateJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreateJobRequestRequestTypeDef",
     {
         "Input": "JobInputTypeDef",
-        "Inputs": List["JobInputTypeDef"],
+        "Inputs": Sequence["JobInputTypeDef"],
         "Output": "CreateJobOutputTypeDef",
-        "Outputs": List["CreateJobOutputTypeDef"],
+        "Outputs": Sequence["CreateJobOutputTypeDef"],
         "OutputKeyPrefix": str,
-        "Playlists": List["CreateJobPlaylistTypeDef"],
-        "UserMetadata": Dict[str, str],
+        "Playlists": Sequence["CreateJobPlaylistTypeDef"],
+        "UserMetadata": Mapping[str, str],
     },
     total=False,
 )
@@ -362,7 +362,7 @@ InputCaptionsTypeDef = TypedDict(
     "InputCaptionsTypeDef",
     {
         "MergePolicy": str,
-        "CaptionSources": List["CaptionSourceTypeDef"],
+        "CaptionSources": Sequence["CaptionSourceTypeDef"],
     },
     total=False,
 )
@@ -371,7 +371,7 @@ JobAlbumArtTypeDef = TypedDict(
     "JobAlbumArtTypeDef",
     {
         "MergePolicy": str,
-        "Artwork": List["ArtworkTypeDef"],
+        "Artwork": Sequence["ArtworkTypeDef"],
     },
     total=False,
 )
@@ -575,7 +575,7 @@ PermissionTypeDef = TypedDict(
     {
         "GranteeType": str,
         "Grantee": str,
-        "Access": List[str],
+        "Access": Sequence[str],
     },
     total=False,
 )
@@ -585,7 +585,7 @@ PipelineOutputConfigTypeDef = TypedDict(
     {
         "Bucket": str,
         "StorageClass": str,
-        "Permissions": List["PermissionTypeDef"],
+        "Permissions": Sequence["PermissionTypeDef"],
     },
     total=False,
 )
@@ -731,7 +731,7 @@ TestRoleRequestRequestTypeDef = TypedDict(
         "Role": str,
         "InputBucket": str,
         "OutputBucket": str,
-        "Topics": List[str],
+        "Topics": Sequence[str],
     },
 )
 
@@ -850,7 +850,7 @@ VideoParametersTypeDef = TypedDict(
     "VideoParametersTypeDef",
     {
         "Codec": str,
-        "CodecOptions": Dict[str, str],
+        "CodecOptions": Mapping[str, str],
         "KeyframesMaxDist": str,
         "FixedGOP": str,
         "BitRate": str,
@@ -863,7 +863,7 @@ VideoParametersTypeDef = TypedDict(
         "DisplayAspectRatio": str,
         "SizingPolicy": str,
         "PaddingPolicy": str,
-        "Watermarks": List["PresetWatermarkTypeDef"],
+        "Watermarks": Sequence["PresetWatermarkTypeDef"],
     },
     total=False,
 )
